pub enum WifiEvent<'a> {
Show 30 variants
Ready,
ScanDone(&'a StaScanDoneRef),
StaStarted,
StaStopped,
StaConnected(&'a StaConnectedRef),
StaDisconnected(&'a StaDisconnectedRef),
StaAuthmodeChanged,
StaBssRssiLow,
StaBeaconTimeout,
StaWpsSuccess(&'a [WpsCredentialsRef]),
StaWpsFailed,
StaWpsTimeout,
StaWpsPin(Option<u32>),
StaWpsPbcOverlap,
ApStarted,
ApStopped,
ApStaConnected(&'a ApStaConnectedRef),
ApStaDisconnected(&'a ApStaDisconnectedRef),
ApProbeRequestReceived,
FtmReport,
ActionTxStatus,
RocDone,
HomeChannelChange(HomeChannelChange),
StaNeighborRep(&'a StaNeighborRepRef),
ApWrongPassword(&'a ApWrongPasswordRef),
StaBeaconOffsetUnstable(&'a StaBeaconOffsetUnstableRef),
DppUriReady(&'a DppUriReadyRef),
DppCfgRecvd(&'a DppCfgRecvdRef),
DppFailed(&'a DppFailedRef),
Other(i32),
}Variants
Ready
ScanDone(&'a StaScanDoneRef)
StaStarted
StaStopped
StaConnected(&'a StaConnectedRef)
StaDisconnected(&'a StaDisconnectedRef)
StaAuthmodeChanged
StaBssRssiLow
StaBeaconTimeout
StaWpsSuccess(&'a [WpsCredentialsRef])
StaWpsFailed
StaWpsTimeout
StaWpsPin(Option<u32>)
StaWpsPbcOverlap
ApStarted
ApStopped
ApStaConnected(&'a ApStaConnectedRef)
ApStaDisconnected(&'a ApStaDisconnectedRef)
ApProbeRequestReceived
FtmReport
ActionTxStatus
RocDone
HomeChannelChange(HomeChannelChange)
StaNeighborRep(&'a StaNeighborRepRef)
Neighbor report received from the AP in response to a neighbor report request from the station.
ApWrongPassword(&'a ApWrongPasswordRef)
A station attempted to connect to the soft-AP with the wrong password.
StaBeaconOffsetUnstable(&'a StaBeaconOffsetUnstableRef)
The station’s beacon offset has become unstable.
DppUriReady(&'a DppUriReadyRef)
A DPP bootstrapping URI is ready to be scanned by the peer.
DppCfgRecvd(&'a DppCfgRecvdRef)
DPP authentication succeeded and a WiFi configuration was received.
DppFailed(&'a DppFailedRef)
DPP authentication or configuration exchange failed.
Other(i32)
An event ID not recognised by this version of the library was received.
This variant is produced instead of panicking when an unknown event ID arrives, allowing applications to remain forward-compatible with ESP-IDF versions that introduce new WiFi events.