StaNeighborRepRef

Struct StaNeighborRepRef 

pub struct StaNeighborRepRef(/* private fields */);
Payload reference for WifiEvent::StaNeighborRep.

The neighbor report bytes are stored in a flexible array member that immediately follows the fixed header in memory.

Implementations

Source

impl StaNeighborRepRef

pub fn report_len(&self) -> usize

Number of bytes in the neighbor report.

pub fn report(&self) -> &[u8]

The raw neighbor report bytes received from the AP.

The slice is reconstructed from the flexible array member (n_report) that immediately follows the fixed header in memory.