pub struct DppUriReadyRef(/* private fields */);Expand description
Payload reference for WifiEvent::DppUriReady.
The URI string is stored in a flexible array member that immediately
follows the fixed header; uri_data_len includes the null terminator.
DppUriReadyRef::uri strips the terminator and returns the URI as a &str.
Implementations
Sourceimpl DppUriReadyRef
impl DppUriReadyRef
Sourcepub fn uri(&self) -> &str
pub fn uri(&self) -> &str
The DPP bootstrapping URI as a string slice (no null terminator).
The slice is reconstructed from the flexible array member
(uri) that immediately follows the fixed header in memory.
DPP bootstrapping URIs are defined by the Wi-Fi Alliance DPP specification to be ASCII-printable, so the bytes are always valid UTF-8.