Struct StaNeighborRepRef
Source pub struct StaNeighborRepRef();
Payload reference for WifiEvent::StaNeighborRep.
The neighbor report bytes are stored in a flexible array member that
immediately follows the fixed header in memory.
Number of bytes in the neighbor report.
The raw neighbor report bytes received from the AP.
The slice is reconstructed from the flexible array member
(n_report) that immediately follows the fixed header in memory.
SourceAvailable on esp_idf_version_at_least_5_3_0 only.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.